pub trait IntervalOps:
EnclosureOps<Midpoint = f64>
+ IntervalDatum
+ From<f64>
+ Neg<Output = Self>
+ Add<Output = Self>
+ Sub<Output = Self>
+ Mul<Output = Self>
+ Div<Output = Self>
+ Add<f64, Output = Self>
+ Sub<f64, Output = Self>
+ Mul<f64, Output = Self>
+ Div<f64, Output = Self>
+ AddAssign
+ SubAssign
+ MulAssign
+ DivAssign
+ AddAssign<f64>
+ SubAssign<f64>
+ MulAssign<f64>
+ DivAssign<f64> {
Show 19 methods
// Required method
fn new(inf: f64, sup: f64) -> Self;
// Provided methods
fn atan2(self, x: Self) -> Self { ... }
fn sign(self) -> Self { ... }
fn ceil(self) -> Self { ... }
fn floor(self) -> Self { ... }
fn trunc(self) -> Self { ... }
fn round_ties_to_even(self) -> Self { ... }
fn round_ties_to_away(self) -> Self { ... }
fn abs(self) -> Self { ... }
fn min(self, other: Self) -> Self { ... }
fn max(self, other: Self) -> Self { ... }
fn hypot(self, other: Self) -> Self { ... }
fn cancel_minus(self, other: Self) -> Self { ... }
fn cancel_plus(self, other: Self) -> Self { ... }
fn hull_value(self, value: f64) -> Self { ... }
fn bisect(self) -> (Self, Self) { ... }
fn inf(self) -> f64 { ... }
fn sup(self) -> f64 { ... }
fn bounds(self) -> (f64, f64) { ... }
}Expand description
Chaining-friendly operations specific to bare and decorated real intervals.
This trait is sealed transitively through IntervalDatum. It can be used
as a public generic bound, but external crates cannot implement it.
Required Methods
Provided Methods
Sourcefn round_ties_to_even(self) -> Self
fn round_ties_to_even(self) -> Self
Rounds pointwise to nearest integers with ties to even.
Sourcefn round_ties_to_away(self) -> Self
fn round_ties_to_away(self) -> Self
Rounds pointwise to nearest integers with ties away from zero.
Sourcefn cancel_minus(self, other: Self) -> Self
fn cancel_minus(self, other: Self) -> Self
Computes cancellative subtraction self ⊖ other.
Sourcefn cancel_plus(self, other: Self) -> Self
fn cancel_plus(self, other: Self) -> Self
Computes cancellative addition self ⊕ other.
Sourcefn hull_value(self, value: f64) -> Self
fn hull_value(self, value: f64) -> Self
Extends this interval’s hull to include value.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".